'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var restApi = require('./rest-api/rest-api.js');
var websocketHandler = require('./websocket/websocket-handler.js');

class ScrapboxApi {
  restApi;
  websocketHandler;

  constructor(token = '', debug = false, restApi$1 = new restApi.RestApi(token), websocketHandler$1 = new websocketHandler.ScrapboxWebsocketHandler({
    token,
    debug
  })) {
    this.restApi = restApi$1;
    this.websocketHandler = websocketHandler$1;
  }

  async getPage(projectName, pageName) {
    return this.restApi.getPage(projectName, pageName);
  }

  async changeLine(projectName, pageName, change) {
    const project = await this.getProject(projectName);
    const {
      pageId,
      commitId
    } = await this.getPageIdAndCommitId(projectName, pageName);
    return this.commit({
      changes: Array.isArray(change) ? change : [change],
      projectId: project.id,
      pageId: pageId,
      commitId: commitId
    });
  }

  async getUser() {
    return await this.restApi.getMe();
  }

  async getProject(projectName) {
    return await this.restApi.getProject(projectName);
  }

  async getPageIdAndCommitId(projectName, pageName) {
    const page = await this.restApi.getPage(projectName, pageName);
    return {
      pageId: page.id,
      commitId: page.commitId
    };
  }

  async commit(param) {
    const user = await this.getUser();
    return this.websocketHandler.commit({
      userId: user.id,
      projectId: param.projectId,
      pageId: param.pageId,
      parentId: param.commitId,
      changes: param.changes
    });
  }

}

exports.ScrapboxApi = ScrapboxApi;
//# sourceMappingURL=scrapbox-api.js.map
