'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var rxjs = require('rxjs');
var operators = require('rxjs/operators');
var constants = require('./constants.js');
var message = require('./internal/message.js');
var request = require('./internal/request.js');
var util = require('./internal/util.js');
var websocket = require('./internal/websocket.js');

class ScrapboxWebsocketHandler {
  options;
  socket$ = new rxjs.BehaviorSubject(null);
  room = null;
  sid = 0;

  constructor(options) {
    this.options = options;
  }

  async commit({
    projectId,
    userId,
    pageId,
    parentId,
    changes
  }) {
    await this.join({
      projectId,
      pageId
    });
    return this.send({
      projectId,
      pageId,
      data: {
        method: 'commit',
        data: {
          kind: 'page',
          userId,
          projectId,
          pageId,
          parentId,
          changes: request.createChanges(changes, userId),
          cursor: null,
          freeze: true
        }
      }
    });
  }

  async join({
    projectId,
    pageId
  }) {
    var _this$room, _this$room2;

    // join room if needed
    if (((_this$room = this.room) === null || _this$room === void 0 ? void 0 : _this$room.projectId) === projectId && ((_this$room2 = this.room) === null || _this$room2 === void 0 ? void 0 : _this$room2.pageId) === pageId) {
      return;
    }

    await this.send({
      projectId,
      pageId,
      data: {
        method: 'room:join',
        data: {
          pageId,
          projectId,
          projectUpdatesStream: false
        }
      }
    });
    this.room = {
      projectId,
      pageId
    };
  }

  send({
    data,
    projectId,
    pageId
  }) {
    const sid = String(this.sid++);
    return rxjs.firstValueFrom(this.getSocket().pipe(operators.first(util.isNotNull), rxjs.mergeMap(socket => socket.send(message.toSocketIoMessagePayload(sid, data)).pipe(operators.first(message.isResponseMessageOf(sid)), operators.timeout(constants.CONFIG.responseTimeout)))));
  }

  getSocket() {
    var _this$socket$$getValu;

    if (!((_this$socket$$getValu = this.socket$.getValue()) !== null && _this$socket$$getValu !== void 0 && _this$socket$$getValu.active)) {
      return this.openNewSocket();
    }

    return this.socket$.asObservable();
  }

  openNewSocket() {
    const socket = new websocket.RxWebSocket({
      url: constants.CONFIG.endpoint,
      options: {
        headers: {
          Origin: constants.CONFIG.origin,
          Cookie: util.getAuthCookieValue(this.options.token ?? '')
        }
      },
      serializer: message.scrapboxSerializer,
      deserializer: message.scrapboxDeserializer,
      debug: this.options.debug
    });
    return socket.message.pipe(operators.first(message.isConnectionMessage), rxjs.mergeMap(([, data]) => {
      return socket.send(constants.packetTypes.connected).pipe(operators.first(message.isResponseOf(constants.packetTypes.connected)), rxjs.mergeMap(() => {
        rxjs.interval(data.pingInterval).pipe(operators.takeUntil(socket.message)).subscribe(() => socket.send(constants.packetTypes.ping));
        this.socket$.next(socket);
        return this.socket$.asObservable();
      }));
    }));
  }

}

exports.ScrapboxWebsocketHandler = ScrapboxWebsocketHandler;
//# sourceMappingURL=websocket-handler.js.map
