import { concat } from 'rxjs';
import { map, share } from 'rxjs/operators';
import { isScrapboxReady, scrapboxReady, nodeChange, findElementOrFail } from './internal/util.js';

class UserScriptApi {
    static pageChange;
    static get data() {
        if (!isScrapboxReady()) {
            throw new Error('window.scrapbox is not set');
        }
        return window.scrapbox;
    }
    static get ready() {
        return scrapboxReady();
    }
    static get update() {
        this.pageChange = this.pageChange || nodeChange(this.pageContainerElement, { childList: true, subtree: true });
        return concat(this.ready, this.pageChange).pipe(map(() => this.data), share());
    }
    static get pageContainerElement() {
        return findElementOrFail('#app-container .page');
    }
    static get pageTitle() {
        return this.data.Page.title || '';
    }
    static get pageLines() {
        return this.data.Page.lines || [];
    }
    static get projectName() {
        return this.data.Project.name;
    }
}

export { UserScriptApi };
//# sourceMappingURL=scrapbox.js.map
